#[derive(ReqwestClient)]
{
// Attributes available to this derive:
#[openapi_trait]
}
Derive the reqwest client carrier trait for a user-owned struct.
By default, the derive expects named fields called client and base_url.
You can override those conventions with field attributes:
#[openapi_trait(client)] and #[openapi_trait(base_url)].